Module: Mana::PromptBuilder
- Included in:
- Engine
- Defined in:
- lib/mana/prompt_builder.rb
Overview
Assembles system prompts and extracts variable context from user prompts. Mixed into Engine as private methods.
Assembles system prompts and extracts variable context from user prompts. Mixed into Engine as private methods.